2014.9.19 2014-09-19
===============
----

* Fix getting custom user model.
* Django > 1.5 < 1.7 support.
* Feature #8: Add Python 3 support.
* Fix #9: Django 1.7 compatibility for test suite.
* Feature: Add pypy support.


2014.6.21 2014-06-21
===============
----

* Add changelog.rst file.
* Add manifest.in file.
* Add license file.
* Run the test out of django-admin.py.
* Remove license header from files.
* Add travis-ci testing ;).
* Fix to make it compatible with django >= 1.5.
* Add ability to specify user class
